gchecky.model.shipping_methods_t

Package gchecky :: Module model :: Class shipping_methods_t |
[hide private]
[frames] | no frames]

# Class shipping_methods_t

source code

    object --+
             |
     gxml.Node --+
                 |
                shipping_methods_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| flat_rate_shippings = `List:PATH():OP`...``
| merchant_calculated_shippings = `List:PATH():OP`...``
| pickups = `List:PATH():OP`...``
| _fields = ``{``'``flat_rate_shippings``'``:` List:PATH():OP`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### flat_rate_shippings Value:
      List:PATH():OPT:[
          Node:PATH(flat-rate-shipping):REQ:{ flat_rate_shipping_t }
      ]

  ### merchant_calculated_shippings Value:
      List:PATH():OPT:[
          Node:PATH(merchant-calculated-shipping):REQ:{ merchant_calculated_
      shipping_t }
      ]

  ### pickups Value:
      List:PATH():OPT:[
          Node:PATH(pickup):REQ:{ pickup_t }
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'flat_rate_shippings': List:PATH():OPT:[
          Node:PATH(flat-rate-shipping):REQ:{ flat_rate_shipping_t }
      ],
       'merchant_calculated_shippings': List:PATH():OPT:[
          Node:PATH(merchant-calculated-shipping):REQ:{ merchant_calculated_
      shipping_t }
      ],
       'pickups': List:PATH():OPT:[
      ...